@@ -19,7 +19,8 @@ public class RNNestedScrollViewPackage implements ReactPackage {
     @Override
     public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
       return Arrays.<ViewManager>asList(
-          new ReactNestedScrollViewManager()
+          new ReactNestedScrollViewManager(),
+          new ReactHorizontalNestedScrollViewManager()
       );
     }
 }
